@@ -93,6 +93,7 @@ libmes_SOURCES="
 $libc_mini_shared_SOURCES
 lib/ctype/isnumber.c
 lib/mes/abtol.c
+lib/mes/cast.c
 lib/mes/eputc.c
 lib/mes/fdgetc.c
 lib/mes/fdputc.c
@@ -106,6 +107,7 @@ lib/mes/ntoab.c
 lib/mes/oputc.c
 lib/mes/ultoa.c
 lib/mes/utoa.c
+lib/stub/__raise.c
 "
 
 if test $mes_libc = mes; then
@@ -113,6 +115,7 @@ if test $mes_libc = mes; then
 lib/ctype/isdigit.c
 lib/ctype/isspace.c
 lib/ctype/isxdigit.c
+lib/mes/assert_msg.c
 lib/posix/write.c
 lib/stdlib/atoi.c
 "
@@ -186,7 +189,7 @@ lib/stub/execve.c
 lib/stub/fork.c
 lib/stub/_getcwd.c
 lib/stub/gettimeofday.c
-lib/stub/ioctl.c
+lib/stub/ioctl3.c
 lib/stub/time.c
 lib/stub/unlink.c
 lib/stub/waitpid.c
@@ -206,7 +209,7 @@ lib/linux/fork.c
 lib/linux/fsync.c
 lib/linux/_getcwd.c
 lib/linux/gettimeofday.c
-lib/linux/ioctl.c
+lib/linux/ioctl3.c
 lib/linux/_open3.c
 lib/linux/malloc.c
 lib/linux/_read.c
@@ -411,6 +414,7 @@ lib/linux/getgid.c
 lib/linux/getppid.c
 lib/linux/getrusage.c
 lib/linux/getuid.c
+lib/linux/ioctl.c
 lib/linux/link.c
 lib/linux/lstat.c
 lib/linux/mkdir.c
@@ -429,7 +433,13 @@ lib/linux/symlink.c
 fi
 
 mes_SOURCES="
+src/builtins.c
+src/cc.c
+src/core.c
+src/display.c
+src/eval-apply.c
 src/gc.c
+src/globals.c
 src/hash.c
 src/lib.c
 src/math.c
@@ -437,7 +447,9 @@ src/mes.c
 src/module.c
 src/posix.c
 src/reader.c
+src/stack.c
 src/string.c
 src/struct.c
+src/symbol.c
 src/vector.c
 "
