@@ -18,11 +18,14 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mes/lib.h>
 #include <linux/syscall.h>
 #include <syscall.h>
 
 int
 access (char const *file_name, int how)
 {
-  return _sys_call2 (SYS_access, (long) file_name, (int) how);
+  long long_file_name = cast_charp_to_long (file_name);
+  long long_how = cast_int_to_long (how);
+  return _sys_call2 (SYS_access, long_file_name, long_how);
 }
