@@ -18,11 +18,13 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mes/lib.h>
 #include <linux/syscall.h>
 #include <syscall.h>
 
 int
 unlink (char const *file_name)
 {
-  return _sys_call1 (SYS_unlink, (long) file_name);
+  long long_file_name = cast_charp_to_long (file_name);
+  return _sys_call1 (SYS_unlink, long_file_name);
 }
