@@ -40,13 +40,6 @@ cell_bytes (struct scm *x)
   return p + (2 * sizeof (long));
 }
 
-char *
-news_bytes (struct scm *x)
-{
-  char *p = cast_voidp_to_charp (x);
-  return p + (2 * sizeof (long));
-}
-
 #define U10 10U
 // CONSTANT U10 10
 #define U100 100U
@@ -219,14 +212,6 @@ copy_cell (struct scm *to, struct scm *from)
   to->cdr = from->cdr;
 }
 
-void
-copy_news (struct scm *to, struct scm *from)
-{
-  to->type = from->type;
-  to->car = from->car;
-  to->cdr = from->cdr;
-}
-
 void
 copy_stack (long index, struct scm *from)
 {
@@ -490,21 +475,21 @@ gc_copy (struct scm *old)               /*:((internal)) */
     return old->car;
   struct scm *new = g_free;
   g_free = g_free + M2_CELL_SIZE;
-  copy_news (new, old);
+  copy_cell (new, old);
   if (new->type == TSTRUCT || new->type == TVECTOR)
     {
       new->vector = g_free;
       long i;
       for (i = 0; i < old->length; i = i + 1)
         {
-          copy_news (g_free, cell_ref (old->vector, i));
+          copy_cell (g_free, cell_ref (old->vector, i));
           g_free = g_free + M2_CELL_SIZE;
         }
     }
   else if (new->type == TBYTES)
     {
       char const *src = cell_bytes (old);
-      char *dest = news_bytes (new);
+      char *dest = cell_bytes (new);
       size_t length = new->length;
       memcpy (dest, src, length);
       g_free = g_free + ((bytes_cells (length) - 1) * M2_CELL_SIZE);
